---
name: Data issue
about: Report an issue Wn's data index
title: ''
labels: data
assignees: ''

---

**If your issue is regarding the contents of the data** (e.g., a lexicon is missing a word, synset, relation, etc.), then please find the upstream project and file the issue there. You can find links to the projects on Wn's [README](https://github.com/goodmami/wn/). Projects without links are probably managed by the [Open Multilingual Wordnet](https://github.com/omwn/omw-data).

**Use this issue template for the following kinds of issues:**
1. Request a wordnet lexicon (including new versions of existing lexicons) to be indexed by Wn

   Please provide:
   - the project name
   - the name and contact info of the current maintainer
   - the language of the lexicon (BCP-47 code preferred)
   - a URL to the project (e.g., on GitHub or other homepage)
   - a URL to the [WN-LMF](https://github.com/globalwordnet/schemas/) resource

2. Report an issue with an indexed lexicon (e.g., the source URL has changed)

   Please indicate the lexicon id and version and the correct project information, if available.
